Lua_ClimbTowerDetailsWindow = class("Lua_ClimbTowerDetailsWindow", Lua_Window);
function Lua_ClimbTowerDetailsWindow:ctor()
	self:superCall("ctor");

	self.windowName = "Lua_ClimbTowerDetailsWindow";
	self.skinName = "ClimbTowerDetailsWindow_skin";
	self.showBlackMask = true;
	self.isClickClose = true;
end

function Lua_ClimbTowerDetailsWindow:buildShowItem()
	self:superCall("buildShowItem");

	self.layerNum = Lua_NumberImage.new(self.content);
	self.layerNum:setLocation(0, 400, 0);
	self.layerNum.pivot = 1;
	self.layerNum.numOffsetX = -12;
	self.layerNum.numAtlas = "number";
	self.layerNum.preStr = "ui_ttt_number_0";

	self.firstAvatar = Lua_AvatarItem.new(self.itemObject_1);
	self.firstAvatar:setLocation(-235, 0, 0);
	self.firstAvatar:setScale(0.7, 0.7, 1);

	self.fastAvatar = Lua_AvatarItem.new(self.itemObject_2);
	self.fastAvatar:setLocation(-235, 0, 0);
	self.fastAvatar:setScale(0.7, 0.7, 1);

	self.lowestAvatar = Lua_AvatarItem.new(self.itemObject_3);
	self.lowestAvatar:setLocation(-235, 0, 0);
	self.lowestAvatar:setScale(0.7, 0.7, 1);

	self.rewardList = Lua_ItemIconList.new(self.content);
	self.rewardList:setLocation(0, -300.5, 0);
	self.rewardList.canClick = true;

	self.btnCheck_1:addClickFuntion(self, self.onCheck1);
	self.btnCheck_2:addClickFuntion(self, self.onCheck2);
	self.btnCheck_3:addClickFuntion(self, self.onCheck3);

	self:addLuaEvent("UPDATE_SINGLETOWER_INFO", self, self.updateServerInfo);
end

function Lua_ClimbTowerDetailsWindow:dispose()
	if self.layerNum ~= nil then
		self.layerNum:dispose();
		self.layerNum = nil;
	end
	if self.firstAvatar ~= nil then
		self.firstAvatar:dispose();
		self.firstAvatar = nil;
	end
	if self.fastAvatar ~= nil then
		self.fastAvatar:dispose();
		self.fastAvatar = nil;
	end
	if self.lowestAvatar ~= nil then
		self.lowestAvatar:dispose();
		self.lowestAvatar = nil;
	end
	if self.rewardList ~= nil then
		self.rewardList:dispose();
		self.rewardList = nil;
	end
	self.data = nil;
	self:superCall("dispose");
end

function Lua_ClimbTowerDetailsWindow:showWin(param)
	self:superCall("showWin", param);

	local config = DataCenter.climbTowerUtil:getTowerConfig(param);
	self.data = DataCenter.climbTowerData:getTowerVoById(config.index);

	self.titleName_1:setAltas("climb_tower_atlas_1", self.data.title_sprite);
	self.titleName_1:resetSize();
	self.layerNum.num = config.storey;
	local width = self.titleName_1.width + self.layerNum.totalWidth + self.titleName_2.width;
	self.titleName_1:setLocation(-width / 2, 400, 0);
	self.layerNum:setLocation(self.titleName_1.posX + self.titleName_1.width - 8, 400, 0);
	self.titleName_2:setLocation(self.layerNum.posX + self.layerNum.totalWidth, 400, 0);
	self.titleDeco_1:setLocation(-width + 50, 400, 0);
	self.titleDeco_2:setLocation(width - 50, 400, 0);

	self:updateRewards(config);
	self:updatePrompt(config);
	Lua_ProxyManager.getProxy("Lua_ClimbTowerProxy"):sSingleTowerInfo(config.index, param);
end

function Lua_ClimbTowerDetailsWindow:updateRewards(config)
	local arr = Array();
	list = config.first_reward;
	local vo;
	for i = 1, #list do
		vo = Lua_ToolVo.createToolVo(list[i][1], list[i][2]);
		arr:add(vo)
	end
	list = config.pass_reward;
	for i = 1, #list do
		vo = Lua_ToolVo.createToolVo(list[i][1], list[i][2]);
		arr:add(vo)
	end
	self.rewardList:setArrayData(arr);
end

function Lua_ClimbTowerDetailsWindow:updatePrompt(config)
    if config.index == Lua_ClimbTowerUtil.LIGHT_ID then
        self.promptText:setEnable(false);
    else
    	self.promptText:setEnable(true);
    	local campName = DataCenter.climbTowerUtil:limitCampName(self.data.limit_camp);
    	self.promptText.text = LanUtil.formateStr(201005, tostring(config.limit_num), campName);
    end
end

function Lua_ClimbTowerDetailsWindow:updateServerInfo(msg)
	if msg == nil then
		return;
	end

	if msg.firstpass_player == nil or tonumber(msg.firstpass_player.id) <= 0 then
		self.firstAvatar:setRoleId(nil);
		self.firstAvatar:setAvatarBg(nil, nil);
		self.firstAvatar:setAvatar("chaos_forest_altas", "ui_hdsl_label_07");
		self.firstAvatar:setRoleFrame(nil);

		self.noneText_1:setEnable(true);
		self.nameText_1:setEnable(false);
		self.timeText_1:setEnable(false);
		self.btnCheck_1:setEnable(false);
	else
		self.firstAvatar:setRoleId(msg.firstpass_player.id);
		self.firstAvatar:setRoleDressUp(msg.firstpass_player.dress_info);

		self.noneText_1:setEnable(false);
		self.nameText_1:setEnable(true);
		self.nameText_1.text = msg.firstpass_player.name;
		self.timeText_1:setEnable(true);
		self.timeText_1.text = LanUtil.formateStr(201006, Lua_TimeTransform.transSeconds8(msg.firstpass_time));
		self.btnCheck_1:setEnable(true);
		self.firstpass_record_id = msg.firstpass_record_id;
	end

	if msg.nearpass_player == nil or tonumber(msg.nearpass_player.id) <= 0 then
		self.fastAvatar:setRoleId(nil);
		self.fastAvatar:setAvatarBg(nil, nil);
		self.fastAvatar:setAvatar("chaos_forest_altas", "ui_hdsl_label_07");
		self.fastAvatar:setRoleFrame(nil);

		self.noneText_2:setEnable(true);
		self.nameText_2:setEnable(false);
		self.timeText_2:setEnable(false);
		self.btnCheck_2:setEnable(false);
	else
		self.fastAvatar:setRoleId(msg.nearpass_player.id);
		self.fastAvatar:setRoleDressUp(msg.nearpass_player.dress_info);

		self.noneText_2:setEnable(false);
		self.nameText_2:setEnable(true);
		self.nameText_2.text = msg.nearpass_player.name;
		self.timeText_2:setEnable(true);
		self.timeText_2.text = LanUtil.formateStr(201006, Lua_TimeTransform.transSeconds8(msg.nearpass_time));
		self.btnCheck_2:setEnable(true);
		self.nearpass_record_id = msg.nearpass_record_id;
	end

	if msg.lowforce_player == nil or tonumber(msg.lowforce_player.id) <= 0 then
		self.lowestAvatar:setRoleId(nil);
		self.lowestAvatar:setAvatarBg(nil, nil);
		self.lowestAvatar:setAvatar("chaos_forest_altas", "ui_hdsl_label_07");
		self.lowestAvatar:setRoleFrame(nil);

		self.noneText_3:setEnable(true);
		self.nameText_3:setEnable(false);
		self.timeText_3:setEnable(false);
		self.btnCheck_3:setEnable(false);
	else
		self.lowestAvatar:setRoleId(msg.lowforce_player.id);
		self.lowestAvatar:setRoleDressUp(msg.lowforce_player.dress_info);
		
		self.noneText_3:setEnable(false);
		self.nameText_3:setEnable(true);
		self.nameText_3.text = msg.lowforce_player.name;
		self.timeText_3:setEnable(true);
		self.timeText_3.text = LanUtil.formateStr(201007, tostring(msg.lowforce_player.force));
		self.btnCheck_3:setEnable(true);
		self.lowforce_record_id = msg.lowforce_record_id;
	end
end

function Lua_ClimbTowerDetailsWindow:onCheck1(go)
	if self.data.new_step > 0 and self.showData >= self.data.new_step then
		Lua_ProxyManager.getProxy("Lua_FightProxy"):sFightReplay(self.firstpass_record_id, 0, nil, 0, 7);
	else
		Lua_ProxyManager.getProxy("Lua_FightProxy"):sFightReplay(self.firstpass_record_id);
	end
end

function Lua_ClimbTowerDetailsWindow:onCheck2(go)
	if self.data.new_step > 0 and self.showData >= self.data.new_step then
		Lua_ProxyManager.getProxy("Lua_FightProxy"):sFightReplay(self.nearpass_record_id, 0, nil, 0, 7);
	else
		Lua_ProxyManager.getProxy("Lua_FightProxy"):sFightReplay(self.nearpass_record_id);
	end
end

function Lua_ClimbTowerDetailsWindow:onCheck3(go)
	if self.data.new_step > 0 and self.showData >= self.data.new_step then
		Lua_ProxyManager.getProxy("Lua_FightProxy"):sFightReplay(self.lowforce_record_id, 0, nil, 0, 7);
	else
		Lua_ProxyManager.getProxy("Lua_FightProxy"):sFightReplay(self.lowforce_record_id);
	end
end