Lua_ClimbTowerWindow = class("Lua_ClimbTowerWindow", Lua_Window);
function Lua_ClimbTowerWindow:ctor()
	self:superCall("ctor");

	self.layer = MainWinDefine.NORMAL_WINDOW_LAYER;	
	self.windowName = "Lua_ClimbTowerWindow";
	self.skinName = "ClimbTowerWindow_skin";
	self.isFullSizeWin = true;
	self.isFullPaving = true;
	self.showWinBg = true;

	self.towerId = 9;
	self.maskPath = "/images/climb_tower/mengban.png";
	self:addPreLoadRes(self.maskPath, Lua_LoadFileType.IMG);
end

function Lua_ClimbTowerWindow:buildShowItem()
	self:superCall("buildShowItem");
	self.dailyIcon:setEnable(false);
	self:createBackBtn(73,73);

	self.yun_up_img:setUrl(self.yunUpPath);
	self.yunArr = Array();
	local item;
	local space = 0;
	local y = 550 + self.adaptHeight/2;
	local startY = Mathf.Random(y, y + 250);
	local uplist = {6,1,2,3,4,5};--云向上循环列表索引
	local downlist = {2,3,4,5,6,1};--云向下循环列表索引
	for i = 1, 6 do
		item = Lua_ClimbTowerYunItem.new(self.content);
		item:setSiblingIndex(i);
		if i > 1 then
			space = Mathf.Random(250, 800);
			startY = self.yunArr[i-1].y;
		end

		if i%2 == 0 then
			item:setLocation(-160, startY - space, 0);
		else
			item:setLocation(160, startY - space, 0);
		end

		item.contentName = "Lua_ClimbTowerYunItem"..i;
		item:setUpIndex(uplist[i]);
		item:setDownIndex(downlist[i]);
		item:setData(i, self.towerId);
		self.yunArr:add(item);
	end

	self.itemList = Lua_DragList.new(self.content, 720, 1400 + self.adaptHeight, Lua_AxisDefine.Vertical);
	self.itemList.movementTypeValue = 2;
	self.itemList:setLocation(0, -20, 0);
	self.itemList:setSiblingIndex(8);
	self.itemList:setListCell(Lua_ClimbTowerItem, 720, 366, 1);
	self.itemList:setCellSpacing(0, -27);
	self.itemList.callBackOwner = self
	self.itemList.dragCallBack = self.updateDragCall;

	self.yun_down_img:setUrl(self.yunDownPath);
	self.yun_down_img.siblingIndex = 7;

	self.maskSpr:setUrl(self.maskPath);
	self.maskSpr.siblingIndex = 9;
	self.maskSpr:SetDimensions(719, 1440 + self.adaptHeight);

	self.rankArr = Array();
	local item;
	for i = 1, 3 do
		item = Lua_ClimbTowerRankMiniItem.new(self.rankObject);
		item:setLocation(-216, -123 - (i - 1) * 42, 0);
		item:setData(i);
		self.rankArr:add(item);
	end

	self.redPoint_Clearance = Lua_RedPointIcon.new(self.content, Lua_RedPointList.ClimbTower_Clearance);
	self.redPoint_Clearance:setRectAnchor(7);
	self.redPoint_Clearance:setLocation(315, 310, 0);

	self:addLuaEvent("UPDATE_TOWER_INFO", self, self.updateShowInfo);
	self:addLuaEvent("TOWER_REWARD_RECEIVE", self, self.onRewardReceive);
	self:addLuaEvent("TOWER_CHECK_DETAILS", self, self.onCheckDetails);

	self.checkHelp:addClickFuntion(self, self.onCheckHelp);
	self.checkRank:addClickFuntion(self, self.onCheckRank);
	self.rewardBg:addClickFuntion(self, self.onCheckReward);
	self.dailyIcon:addClickFuntion(self, self.onCheckDailyReward);
	self.btnChallenge:addClickFuntion(self, self.onBtnChallengeClick);

	self:onRequestInfo()
end

function Lua_ClimbTowerWindow:onBackBtnClick()
	if DataCenter.climbTowerData:checkCampTowerIsOpen() then
		DataCenter.funcPathUtil:gotoFunction(1010, true, false);
	else
		DataCenter.funcPathUtil:gotoFunction(1047, true, false);
	end
end

function Lua_ClimbTowerWindow:dispose()
	DataCenter.preLoadData:removeBySign("Lua_TowerLineupWindow", self, self.onSceneShow);
	if self.itemList ~= nil then
		self.itemList:dispose();
		self.itemList = nil;
	end
	if self.rankArr ~= nil then
		self.rankArr:dispose();
		self.rankArr:clear();
		self.rankArr = nil;
	end
	if self.yunArr ~= nil then
		self.yunArr:dispose();
		self.yunArr:clear();
		self.yunArr = nil;
	end

	if self.redPoint_Clearance ~= nil then
		self.redPoint_Clearance:dispose();
		self.redPoint_Clearance = nil;
	end
	if self.redPoint_Daily ~= nil then
		self.redPoint_Daily:dispose();
		self.redPoint_Daily = nil;
	end
	self.data = nil;
	self:superCall("dispose");
end

function Lua_ClimbTowerWindow:updateDragCall(subPos)
	local speed = 0.05;
	local diff = subPos - self.curSubPos;
	local value = 1440 + self.adaptHeight;
	local bool = diff >= 0;--true 列表向上滑动（云方向与列表相反）
	local border_y = bool and -value/2 - 145 or value/2 +145;--边界Y值
	self.curSubPos = subPos;
	
	-- print(bool,"  边界  = =",border_y)
	
	local x;
	local y;
	local space;
	local len = self.yunArr:getSize();
	for i=1, len do
		x = self.yunArr[i].x;
		y = self.yunArr[i].y + -diff*speed;
		if bool then--云向下
			if y <= border_y then
				local downIndex = self.yunArr[i].downIndex;
				space = Mathf.Random(250, 800);
				y = self.yunArr[downIndex].y + space;
			end
		else--云向上
			if y >= border_y then
				local upIndex = self.yunArr[i].upIndex;
				space = Mathf.Random(250, 800);
				y = self.yunArr[upIndex].y - space;
			end
		end
		self.yunArr[i]:setLocation(x, y, 0);
	end
end

function Lua_ClimbTowerWindow:onScreenResize()
	self:superCall("onScreenResize");
	self.maskSpr:SetDimensions(719, 1440 + self.adaptHeight);
	self.itemList:setContentRect(720, 1400 + self.adaptHeight);
end

function Lua_ClimbTowerWindow:showWin(param)
	self:superCall("showWin",param)
	local towerId;
	if type(param) == "table" then
		towerId = param.main_id;
	elseif type(param) == "number" then
		towerId = param;
	end

	if towerId == self.towerId then
		return
	end
	self.towerId = towerId;
	self:onRequestInfo()
end

function Lua_ClimbTowerWindow:onRequestInfo()
	self.data = DataCenter.climbTowerData:getTowerVoById(self.towerId);
	if self.data.bInitServer then
		self:updateShowInfo();
	else
		Lua_ProxyManager.getProxy("Lua_ClimbTowerProxy"):sTowerInfo(self.towerId);
	end

	if self.yunArr ~= nil then
		for i = 1, self.yunArr:getSize() do
			self.yunArr[i]:setData(i, self.towerId);
		end
	end
end

function Lua_ClimbTowerWindow:updateShowInfo()
	if self.data == nil then
		self.data = DataCenter.climbTowerData:getTowerVoById(self.towerId);
	end
	self.titleText.text = self.data.name;

	local arr = DataCenter.climbTowerUtil:getTowerArrByType(self.towerId, self.data.cur_stage_storey)
	local index = arr:indexOf(self.data.cur_stage_id)
	self.itemList:setArrayData(arr);
	self.itemList:moveToIndex(index + 2, true, true);
	self.curSubPos = self.itemList.curSubPos;

	local des, tvo = DataCenter.climbTowerUtil:getRewardInfo(self.towerId);
	if tvo == nil then
		self.rewardObject:SetActive(false);
		self.redPoint_Clearance:setEnable(false);
	else
		self.rewardObject:SetActive(true);
		self.rewardIcon:setAltas(tvo.atlas, tvo.sprite);
		self.rewardText.text = des;
		self.redPoint_Clearance:setEnable(true);
	end

	self.dailyIcon:setEnable(self.towerId == Lua_ClimbTowerUtil.LIGHT_ID);
	if self.towerId == Lua_ClimbTowerUtil.LIGHT_ID and self.redPoint_Daily == nil then
		self.redPoint_Daily = Lua_RedPointIcon.new(self.content, Lua_RedPointList.ClimbTower_9_Daily);
		self.redPoint_Daily:setRectAnchor(7);
		self.redPoint_Daily:setLocation(315, 200, 0);
	end

	self:updateRankInfo()
end

function Lua_ClimbTowerWindow:updateRankInfo()
	local list = self.data.top_ranker
	-- table.sort( list, function(a, b) return a.rank < b.rank end);
	local len = #list;
	for i = 1, 3 do
		if len >= i then
			self.rankArr[i]:setData(i, list[i]);
		else
			self.rankArr[i]:setData(i, nil);
		end
	end
end

function Lua_ClimbTowerWindow:onRewardReceive(stageId)
	Lua_ProxyManager.getProxy("Lua_ClimbTowerProxy"):sReceiveTowerReward(self.towerId, stageId);
end

function Lua_ClimbTowerWindow:onCheckDetails(stageId)
	Lua_WindowUtil.openWin("Lua_ClimbTowerDetailsWindow", Lua_WinParam.ACTION_OPEN, stageId);
end

function Lua_ClimbTowerWindow:onCheckHelp(go)
	local tipsData = { des = self.data.rule, posX = 213, posY = -170 };
	Lua_WindowUtil.openWin("Lua_InstructionTipsWindow", Lua_WinParam.ACTION_OPEN, tipsData);
end

function Lua_ClimbTowerWindow:onCheckRank(go)
	DataCenter.funcPathUtil:gotoFunction(self.data.rank_path_id)
end

function Lua_ClimbTowerWindow:onCheckReward(go)
	Lua_WindowUtil.openWin("Lua_ClimbTowerRewardWindow", Lua_WinParam.ACTION_OPEN, self.data.sort);
end

function Lua_ClimbTowerWindow:onCheckDailyReward(go)
	Lua_WindowUtil.openWin("Lua_ClimbTowerDailyRewardWindow", Lua_WinParam.ACTION_OPEN, self.towerId);
end

function Lua_ClimbTowerWindow:onBtnChallengeClick(go)
	if self.data.isLimit == true then
		OperateAlert.showLangValue(201001);
		return;
	end

	if self.data.cur_stage_state == 1 then
		OperateAlert.showLangValue(201021);
		return;
	end

	local sceneId = DataCenter.heroLineupData:getFightLineupSceneId(self.data.fight_id);
	DataCenter.preLoadData:preShowScene("Lua_TowerLineupWindow", Lua_PreLoadDefine.LOADSHOW_TYPE_NONE, self, self.onSceneShow, nil, sceneId, 0);
end

function Lua_ClimbTowerWindow:onSceneShow(param, mp, success)
	if not success then return; end
	Lua_WindowUtil.openWin("Lua_TowerLineupWindow", Lua_WinParam.ACTION_OPEN, self.data);
end





















Lua_ClimbTowerItem = class("Lua_ClimbTowerItem", Lua_ListCell);
function Lua_ClimbTowerItem:ctor(p)
	self:superCall("ctor", p, "ClimbTowerItem_skin");
end

function Lua_ClimbTowerItem:buildShowItem()
	self:superCall("buildShowItem");
	self.checkDetails:addClickFuntion(self, self.onCheckDetails);
end

function Lua_ClimbTowerItem:dispose()
	if self.modelEffImg ~= nil then
		self.modelEffImg:dispose();
		self.modelEffImg = nil;
	end
	if self.extraItem ~= nil then
		self.extraItem:dispose();
		self.extraItem = nil;
	end
	self:superCall("dispose");
end

function Lua_ClimbTowerItem:setData(id)
	self.id = id;
	local config = DataCenter.climbTowerUtil:getTowerConfig(id);
	self.layerText.text = config.storey;
	local index = config.index;
	self.rewardState = DataCenter.climbTowerData:getStageRewardState(index, id);

	local config1 = DataCenter.climbTowerUtil:getRewardConfig(id);
	if config1 == nil then
		self.bg:setUrl("/images/climb_tower/putong_"..index..".png");
		self.layerText:setLocation(0,99, 0);
		self.checkDetails:setLocation(52, 96, 0);
		self:setReward(nil);
		self.curSelectType = 1;
	else
		self.bg:setUrl("/images/climb_tower/boss_"..index..".png");
		self.layerText:setLocation(0, 91, 0);
		self.checkDetails:setLocation(52, 88, 0);
		self.curSelectType = 2;
		
		if self.rewardState == 2 then
			self:setReward(nil);
		else
			self:setReward(config1.reward);
		end
	end

	local vo = DataCenter.climbTowerData:getTowerVoById(index);
	if vo.cur_stage_state == 1 or config.storey < vo.cur_stage_storey then -- 已通关
		self.doorMask:setEnable(false);
		self.checkDetails:setEnable(true);
		self.completedIcon:setEnable(true);
		self:setSelected(false);
		self:showModel(nil);
	else
		self.completedIcon:setEnable(false);
		if config.storey == vo.cur_stage_storey then
			self.doorMask:setEnable(false);
			self.checkDetails:setEnable(true);
			self:setSelected(true);
			self:showModel(config.robot);
		else
			self.doorMask:setEnable(true);
			self.checkDetails:setEnable(false);
			self:setSelected(false);
			self:showModel(nil);
		end
	end
end

function Lua_ClimbTowerItem:setSelected(bSelected)
	if bSelected then
		if self.selectedImg == nil then
			self.selectedImg = UICreate.createImage(self.content, nil, 0, 0, 707, 420);
			-- self.selectedImg.siblingIndex = 0
		end
		if self.curSelectType == 2 then
			self.selectedImg:setUrl("/images/climb_tower/xui_ttt_toggle_1_f.png");
		else
			self.selectedImg:setUrl("/images/climb_tower/xui_ttt_toggle_2_f.png");
		end
		self.selectedImg:setEnable(true);
	else
		if self.selectedImg ~= nil then
			self.selectedImg:setEnable(false);
		end
	end
end

function Lua_ClimbTowerItem:showModel(monsterId)
	if monsterId == nil then
		if self.modelEffImg ~= nil then
			self.modelEffImg:setEnable(false);
		end
	else
		local monsterConfig = Lua_MonsterPlayerConfigData.getConfigData(monsterId);
		monsterId = monsterConfig.fighter_list[1][1][1];
		monsterConfig = Lua_MonsterConfigData.getMonsterConfig(monsterId);
		if self.modelEffImg == nil then
			self.modelEffImg = UICreate.createModelEffImg(self.content, nil, nil, 0, -34, 161, 161);
			self.modelEffImg:setCamField(1, 1, 100, true);
			self.modelEffImg:setCamPos(0, 1, -10);
			self.modelEffImg:setModelEffDir(180);
			self.modelEffImg.canRot = false;
		end
		self.modelEffImg:setEnable(true);
		self.modelEffImg:setUrl(monsterConfig.heroVo.modelUrl, monsterConfig.heroVo.modelSrc);
	end
end

function Lua_ClimbTowerItem:setReward(reward)
	if reward == nil then
		self.rewardBg:setEnable(false);
		if self.extraItem ~= nil then
			self.extraItem:setEnable(false);
		end
	else
		self.rewardBg:setEnable(true);
		if self.extraItem == nil then
			self.extraItem = Lua_ItemIcon.new(self.content);
			self.extraItem:setLocation(-175, -17, 0);
			self.extraItem:setScale(0.8, 0.8, 0.8)
			self.extraItem:setClick(self, self.onItemClick);
		end
		self.extraItem:setEnable(true);
		local tvo = Lua_ToolVo.createToolVo(reward[1][1], reward[1][2]);
		self.extraItem:setData(tvo);
		self.extraItem:showRedPoint(self.rewardState == 1);
	end
end

function Lua_ClimbTowerItem:onItemClick(data)
	if self.rewardState == 1 then
		Lua_MsgUtil.callFunc("TOWER_REWARD_RECEIVE", self.id);
	else
		DataCenter.packUtil:showItemInfo(data);
	end
end

function Lua_ClimbTowerItem:onCheckDetails(go)
	Lua_MsgUtil.callFunc("TOWER_CHECK_DETAILS", self.id);
end






















Lua_ClimbTowerRankMiniItem = class("Lua_ClimbTowerRankMiniItem", Lua_ListCell);
function Lua_ClimbTowerRankMiniItem:ctor(p)
	self:superCall("ctor", p, "ClimbTowerRankMiniItem_skin");
end

function Lua_ClimbTowerRankMiniItem:buildShowItem()
	self:superCall("buildShowItem");
end

function Lua_ClimbTowerRankMiniItem:dispose()
	self:superCall("dispose");
end

function Lua_ClimbTowerRankMiniItem:setData(rank, data)
	self.rankIcon:setAltas("climb_tower_atlas_1", "ui_ttt_title_0"..rank);
	self.rankIcon:resetSize();
	if data == nil then
		self.nameText:setLangValue(201002);
		self.layerText.text = "";
	else
		self.nameText.text = Lua_ColorDefine.getColorStr("FFED9A", data.player_show.name);
		self.layerText.text = LanUtil.formateStr(201000, tostring(data.value));
	end
end














Lua_ClimbTowerYunItem = class("Lua_ClimbTowerYunItem", Lua_DisplayObject);
function Lua_ClimbTowerYunItem:ctor(p)
	self:superCall("ctor", p);
end

function Lua_ClimbTowerYunItem:buildShowItem()
	self:superCall("buildShowItem");
	self.yunBg = UICreate.createImage(self.content, "/images/climb_tower/yun1_9.png", 0, 0, 0, 0);
end

function Lua_ClimbTowerYunItem:dispose()
	self.yunBg = nil;
	self:superCall("dispose");
end

function Lua_ClimbTowerYunItem:setData(index, towerId)
	if index%2 == 0 then
		self.yunBg:setUrl("/images/climb_tower/yun1_"..towerId..".png");
		self.yunBg:setLocation(0,0,0);
		self.yunBg:SetDimensions(403,463);
	else
		self.yunBg:setUrl("/images/climb_tower/yun2_"..towerId..".png");
		self.yunBg:setLocation(50,0,0);
		self.yunBg:SetDimensions(299,262);
	end
end

function Lua_ClimbTowerYunItem:setUpIndex(value)
	self.upIndex = value;
end

function Lua_ClimbTowerYunItem:setDownIndex(value)
	self.downIndex = value;
end